pygeodesy.ellipsoidalBase.CartesianEllipsoidalBase

Package pygeodesy :: Module ellipsoidalBase :: Class CartesianEllipsoidalBase |
[frames] | no frames]

# Class CartesianEllipsoidalBase

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
    vector3dBase.Vector3dBase --+
                                |
                vector3d.Vector3d --+
                                    |
                   object --+       |
                            |       |
                 named._Named --+   |
                                |   |
            ecefLocals._EcefLocal --+
                                    |
          cartesianBase.CartesianBase --+
                                        |
                                       CartesianEllipsoidalBase

Known Subclasses:
  - ellipsoidalExact.Cartesian
  - , ellipsoidalGeodSolve.Cartesian
  - , ellipsoidalKarney.Cartesian
  - , ellipsoidalNvector.Cartesian
  - , ellipsoidalVincenty.Cartesian

(INTERNAL) Base class for ellipsoidal `Cartesian`s.

Instance Methods
__init__(self, x_xyz, y=None, z=None, reframe=None, epoch=None, **datum_ll_name) New ellispoidal `Cartesian...`. |
convertRefFrame(self, reframe2, reframe, epoch=None) DEPRECATED, use method toRefFrame. |
intersections2(self, radius, center2, radius2, sphere=True, Vector=None, **Vector_kwds) Compute the intersection of two spheres or circles, each defined by a cartesian center point and a radius. |
toLatLon(self, datum=None, height=None, **LatLon_and_kwds) Convert this cartesian to a geodetic (lat-/longitude) point. |
toRefFrame(self, reframe2, reframe=None, epoch=None, epoch2=None, **name) Convert this point to an other reference frame and epoch. |
toTransforms_(self, *transforms, **datum) DEPRECATED on 2024.02.14, use method `toTransform`. |
Inherited from `cartesianBase.CartesianBase`: `Roc2`, `cassini`, `collins`, `collins5`, `convertDatum`, `destinationXyz`, `hartzell`, `height3`, `height4`, `pierlot`, `pierlotx`, `tienstra`, `tienstra7`, `to2ab`, `to2ll`, `to3llh`, `toDatum`, `toEcef`, `toNvector`, `toRtp`, `toStr`, `toTransform`, `toVector` Inherited from `vector3d.Vector3d`: `bearing`, `circin6`, `circum3`, `circum4_`, `iscolinearWith`, `meeus2`, `nearestOn`, `nearestOn6`, `parse`, `radii11`, `soddy4`, `toCartesian`, `trilaterate2d2`, `trilaterate3d2` Inherited from `vector3dBase.Vector3dBase`: `__abs__`, `__add__`, `__bool__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__ipow__`, `__isub__`, `__itruediv__`, `__le__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__sub__`, `__truediv__`, `__trunc__`, `angleTo`, `apply`, `bools`, `cmp`, `cross`, `dividedBy`, `dividedBy_`, `dot`, `equals`, `equirectangular`, `fabs`, `floats`, `floorDividedBy`, `floorDividedBy_`, `intermediateTo`, `ints`, `isconjugateTo`, `isequalTo`, `minus`, `minus_`, `negate`, `others`, `plus`, `plus_`, `pow`, `rotate`, `rotateAround`, `sum`, `times`, `times_`, `to3xyz`, `unit` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `toRepr` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| ellipsoidalCartesian Get this `Cartesian`'s ellipsoidal class.
| epoch Class `property` with a `.name` attribute.
| reframe Class `property` with a `.name` attribute.
Inherited from `cartesianBase.CartesianBase`: `datum`, `height`, `isEllipsoidal`, `isSpherical`, `latlon`, `latlonheight`, `latlonheightdatum`, `philam`, `philamheight`, `philamheightdatum`, `sphericalCartesian` Inherited from `vector3dBase.Vector3dBase`: `crosserrors`, `euclid`, `homogeneous`, `length`, `length2`, `x`, `x2y2z2`, `x2y2z23`, `xyz`, `xyz3`, `y`, `z` Inherited from `ecefLocals._EcefLocal`: `Ecef` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, x_xyz, y=None, z=None, reframe=None, epoch=None, **datum_ll_name) (Constructor) |
New ellispoidal `Cartesian...`. Arguments: `reframe` - Optional reference frame (RefFrame). `epoch` - Optional epoch to observe for `reframe` (`scalar`), a non-zero, fractional calendar year; silently ignored if `reframe=None`. Raises: `TypeError` - Non-scalar `x_xyz`, `y` or `z` coordinate or `x_xyz` not a `Cartesian` Ecef9Tuple, Vector3Tuple or Vector4Tuple or `datum` is not a Datum, `reframe` is not a RefFrame or `epoch` is not `scalar` non-zero. Overrides: object.__init__ See Also: Class CartesianBase for more details.

### convertRefFrame (self, reframe2, reframe, epoch=None) |
DEPRECATED, use method toRefFrame. Decorators: `@deprecated_method`

### intersections2 (self, radius, center2, radius2, sphere=True, Vector=None, **Vector_kwds) |
Compute the intersection of two spheres or circles, each defined by a cartesian center point and a radius. Arguments: `radius` - Radius of this sphere or circle (same units as this point's coordinates). `center2` - Center of the second sphere or circle (`Cartesian`, Vector3d, `Vector3Tuple` or `Vector4Tuple`). `radius2` - Radius of the second sphere or circle (same units as this and the `other` point's coordinates). `sphere` - If `True`, compute the center and radius of the intersection of two spheres. If `False`, ignore the `z`-component and compute the intersection of two circles (`bool`). `Vector` - Class to return intersections (`Cartesian`, Vector3d or `Vector3Tuple`) or `None` for an instance of this (sub-)class. `Vector_kwds` - Optional, additional `Vector` keyword arguments, ignored if `Vector is None`. Returns: If `sphere is True`, a 2-tuple of the `center` and `radius` of the intersection of the spheres. The `radius` is `0.0` for abutting spheres (and the `center` is aka the radical center). If `sphere is False`, a 2-tuple with the two intersection points of the circles. For abutting circles, both points are the same instance (aka the radical center). Raises: `IntersectionError` - Concentric, invalid or non-intersecting spheres or circles. `TypeError` - Invalid `center2`. `UnitError` - Invalid `radius` or `radius2`. See Also: Sphere-Sphere, Circle-Circle Intersection and function pygeodesy.radical2.

### toLatLon (self, datum=None, height=None, **LatLon_and_kwds) |
Convert this cartesian to a geodetic (lat-/longitude) point. Arguments: `datum` - Optional datum (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `height` - Optional height, overriding the converted height (`meter`), only if `LatLon is not None`. `LatLon` - Optional class to return the geodetic point (`LatLon`) or `None`. `LatLon_kwds` - Optional, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: The geodetic point (`LatLon`) or if `LatLonis None`, an Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with `C` and `M` if available. Raises: `TypeError` - Invalid `datum` or `LatLon_kwds`. Overrides: cartesianBase.CartesianBase.toLatLon See Also: Method toLatLon for further details.

### toRefFrame (self, reframe2, reframe=None, epoch=None, epoch2=None, **name) |
Convert this point to an other reference frame and epoch. Arguments: `reframe2` - Reference frame to convert to (RefFrame). `reframe` - Optional reference frame to convert from (RefFrame), overriding this point's reference frame. `epoch` - Optional epoch (Epoch, `scalar` or `str`), overriding this point's `epoch or reframe.epoch`. `epoch2` - Optional epoch to observe for the converted point (Epoch, `scalar` or `str`), otherwise `epoch`. `name` - Optional `name=NN` (`str`), overriding `reframe2.name`. Returns: The converted point (ellipsoidal `Cartesian`) or if conversion `isunity`, this point or a copy of this point if the `name` is non-empty. Raises: `TRFError` - This point's `reframe` is not defined, invalid `epoch` or `epoch2` or conversion from this point's `reframe` to `reframe2` is not available. `TypeError` - `reframe2` or `reframe` not a RefFrame.

### toTransforms_ (self, *transforms, **datum) |
DEPRECATED on 2024.02.14, use method `toTransform`. Decorators: `@deprecated_method`

Property Details

### ellipsoidalCartesian Get this `Cartesian`'s ellipsoidal class. Get method: ellipsoidalCartesian(self) - Get this `Cartesian`'s ellipsoidal class. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### epoch Class `property` with a `.name` attribute. Get method: epoch(self) - Get this cartesian's observed or `reframe` epoch (`Epoch`) or `None`. Set method: epoch(self, epoch) - Set or clear this cartesian's observed epoch, a fractional calendar year (Epoch, `scalar` or `str`) or `None`.

### reframe Class `property` with a `.name` attribute. Get method: reframe(self) - Get this cartesian's reference frame (RefFrame) or `None`. Set method: reframe(self, reframe) - Set or clear this cartesian's reference frame (RefFrame) or `None`.